pub trait PrehashSignature {
type Digest: Digest;
}Expand description
Marker trait for Signature types computable as ๐(๐(๐))
i.e. ones which prehash a message to be signed as ๐(๐)
Where:
๐: signature algorithm๐: hash (a.k.a. digest) function๐: message
This approach is relatively common in signature schemes based on the Fiat-Shamir heuristic.
For signature types that implement this trait, when the derive crate
feature is enabled a custom derive for Signer is available for any
types that impl DigestSigner, and likewise for deriving Verifier for
types which impl DigestVerifier.
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".